diff -ruN -x configure -x *~ -x ircd-hybrid-6.0.orig -x *.rej ircd-hybrid-6.0.orig/include/client.h ircd-hybrid-6.0/include/client.h
--- ircd-hybrid-6.0.orig/include/client.h	Sat Jun  9 17:59:46 2001
+++ ircd-hybrid-6.0/include/client.h	Sat Jun  9 16:46:30 2001
@@ -408,6 +408,7 @@
 #define UMODE_HIGHPRIORITY   44
 #define UMODE_GRANT          45
 #define UMODE_SENDOPERWALL   46
+#define UMODE_SEEOPERPRIVS   47
 
 /* *sigh* overflow flags */
 #define FLAGS2_RESTRICTED   0x0001      /* restricted client */
@@ -500,6 +501,7 @@
 
 #define SeesOperMessages(x)     (TestBit((x)->umodes,UMODE_OPER))
 #define SeesOpers(x)            (TestBit((x)->umodes,UMODE_SEESOPERS))
+#define SeesOperPrivs(x)        (TestBit((x)->umodes,UMODE_SEEOPERPRIVS))
 #define SendWhileLifeSucks(x)   (TestBit((x)->umodes,UMODE_HIGHPRIORITY))
 #define IsAlwaysBusy(x)         (TestBit((x)->umodes,UMODE_HIGHPRIORITY))
 /* This one means no protection against *this* client flooding */
diff -ruN -x configure -x *~ -x ircd-hybrid-6.0.orig -x *.rej ircd-hybrid-6.0.orig/include/numeric.h ircd-hybrid-6.0/include/numeric.h
--- ircd-hybrid-6.0.orig/include/numeric.h	Sat Jun  9 17:59:45 2001
+++ ircd-hybrid-6.0/include/numeric.h	Sat Jun  9 17:03:05 2001
@@ -239,6 +239,10 @@
 #define RPL_LISTEND          323
 #define RPL_CHANNELMODEIS    324
 
+#define RPL_WHOISOPER_GOD    325
+#define RPL_WHOISOPER_PRIVS  326
+#define RPL_WHOISOPER_NOTGOD 327
+
 #define RPL_CREATIONTIME     329
 
 #define RPL_NOTOPIC          331
diff -ruN -x configure -x *~ -x ircd-hybrid-6.0.orig -x *.rej ircd-hybrid-6.0.orig/include/umodes.h ircd-hybrid-6.0/include/umodes.h
--- ircd-hybrid-6.0.orig/include/umodes.h	Sat Jun  9 17:59:46 2001
+++ ircd-hybrid-6.0/include/umodes.h	Sat Jun  9 16:47:01 2001
@@ -71,6 +71,7 @@
   {UMODE_REMOTE, 'R'},
   {UMODE_SERVNOTICE, 's'},
   {UMODE_UNKLINE, 'U'},
+  {UMODE_SEEOPERPRIVS, 'v'},
   {UMODE_WALLOP, 'w'},
   {UMODE_SENDWALLOPS, 'W'},
   {UMODE_EXTERNAL, 'x'},
diff -ruN -x configure -x *~ -x ircd-hybrid-6.0.orig -x *.rej ircd-hybrid-6.0.orig/src/m_whois.c ircd-hybrid-6.0/src/m_whois.c
--- ircd-hybrid-6.0.orig/src/m_whois.c	Sat Jun  9 17:59:46 2001
+++ ircd-hybrid-6.0/src/m_whois.c	Sat Jun  9 17:14:40 2001
@@ -290,8 +290,19 @@
                && SeesOpers(sptr)
 #endif
               )
-            sendto_one(sptr, form_str(RPL_WHOISOPERATOR),
-                       me.name, parv[0], name);
+	    {
+	      sendto_one(sptr, form_str(RPL_WHOISOPERATOR),
+			 me.name, parv[0], name);
+	      if (IsSetOperGod(acptr) || IsSetOperGline(acptr) || IsSetOperK(acptr) || IsSetOperGlobalKill(acptr))
+		sendto_one(sptr, form_str(RPL_WHOISOPER_GOD),
+			   me.name, parv[0], name);
+	      else
+		sendto_one(sptr, form_str(RPL_WHOISOPER_NOTGOD),
+			   me.name, parv[0], name);
+	      if (SeesOperPrivs(sptr))
+		sendto_one(sptr, form_str(RPL_WHOISOPER_PRIVS),
+			   me.name, parv[0], name, oper_flags_as_string(acptr->allowed_umodes));
+	    }
 
           if (IsIdentifiedNick(acptr))
             sendto_one(sptr, form_str(RPL_WHOISIDENTIFIED),
diff -ruN -x configure -x *~ -x ircd-hybrid-6.0.orig -x *.rej ircd-hybrid-6.0.orig/src/messages_cust.tab ircd-hybrid-6.0/src/messages_cust.tab
--- ircd-hybrid-6.0.orig/src/messages_cust.tab	Sat Jun  9 17:59:45 2001
+++ ircd-hybrid-6.0/src/messages_cust.tab	Sat Jun  9 17:53:12 2001
@@ -266,7 +266,7 @@
 /* 239 */       (char *)NULL,
 /* 240 */       (char *)NULL,
 /* 241 RPL_STATSLLINE, */       ":%s 241 %s %c %s * %s %d %d",
-/* 242 RPL_STATSUPTIME,*/       ":%s 242 %s :Server up %d days, %d:%02d:%02d since Dianora messed with the code",
+/* 242 RPL_STATSUPTIME,*/       ":%s 242 %s :Server up %d days, %d:%02d:%02d since somebody threw me together",
 /* 243 RPL_STATSOLINE, */       ":%s 243 %s %c %s@%s * %s %s %d %s",
 /* 244 RPL_STATSHLINE, */       ":%s 244 %s %c %s * %s %d %d", 
 /* 245 RPL_STATSSLINE, */       ":%s 245 %s %c %s * %s %d %d", 
@@ -278,8 +278,8 @@
 /* 250 RPL_STATSCONN, */
                     ":%s 250 %s :Highest connection count: %d (%d clients) (%d since server was (re)started)",
 /* 251 RPL_LUSERCLIENT, */
-                ":%s 251 %s :There are %d victims and %d invisible on %d servers",
-/* 252 RPL_LUSEROP, */          ":%s 252 %s %d :minor deities online",
+                ":%s 251 %s :There are %d victims and %d hiding on %d servers",
+/* 252 RPL_LUSEROP, */          ":%s 252 %s %d :loyal followers online",
 /* 253 RPL_LUSERUNKNOWN, */     ":%s 253 %s %d :unknown connection(s)",
 /* 254 RPL_LUSERCHANNELS, */    ":%s 254 %s %d :channels formed",
 /* 255 RPL_LUSERME, */          ":%s 255 %s :I have %d clients and %d servers",
@@ -341,7 +341,7 @@
 /* 310 */       (char *)NULL,
 /* 311 RPL_WHOISUSER, */        ":%s 311 %s %s %s %s * :%s",
 /* 312 RPL_WHOISSERVER, */      ":%s 312 %s %s %s :%s",
-/* 313 RPL_WHOISOPERATOR, */    ":%s 313 %s %s :is a deity of the small screen",
+/* 313 RPL_WHOISOPERATOR, */    ":%s 313 %s %s :is a known lemming",
 /* 314 RPL_WHOWASUSER, */       ":%s 314 %s %s %s %s * :%s",
 /* 315 RPL_ENDOFWHO, */         ":%s 315 %s %s :End of /WHO list.",
 /* 316 RPL_WHOISCHANOP, */      (char *)NULL,
@@ -353,9 +353,9 @@
 /* 322 RPL_LIST, */             ":%s 322 %s %s %d :%s",
 /* 323 RPL_LISTEND, */          ":%s 323 %s :End of /LIST",
 /* 324 RPL_CHANNELMODEIS, */    ":%s 324 %s %s %s %s",
-/* 325 */       (char *)NULL,
-/* 326 */       (char *)NULL,
-/* 327 */       (char *)NULL,
+/* 325 RPL_WHOISOPER_GOD */     ":%s 325 %s %s :is a deity of the small screen",
+/* 326 RPL_WHOISOPER_PRIVS */   ":%s 326 %s %s :has oper privs: %s",
+/* 327 RPL_WHOISOPER_NOTGOD */  ":%s 325 %s %s :is a lowly acolyte",
 /* 328 */       (char *)NULL,
 /* 329 RPL_CREATIONTIME, */      ":%s 329 %s %s %lu", 
 /* 330 */       (char *)NULL,
@@ -421,7 +421,7 @@
 /* 378 RPL_ENDOFMAP */          ":%s 378 %s :End of /MAP list.",
 /* 379 RPL_FORWARD */           ":%s 379 %s :Forwarding from %s to %s",
 /* 380 */       (char *)NULL,
-/* 381 RPL_YOUREOPER, */        ":%s 381 %s :You are now a deity -- be nice or else!",
+/* 381 RPL_YOUREOPER, */        ":%s 381 %s :You are now a loyal follower -- be nice or else!",
 /* 382 RPL_REHASHING, */        ":%s 382 %s %s :Rehashing the server configuration file, dear.",
 /* 383 */       (char *)NULL,
 /* 384 RPL_MYPORTIS, */         ":%s 384 %s %d :Port to local server is\r\n",
@@ -480,7 +480,7 @@
 /* 435 */       (char *)NULL,
 /* 436 ERR_NICKCOLLISION, */    ":%s 436 %s %s :Nickname collision KILL",
 /* 437 ERR_NOTAVAILABLE, */     ":%s 437 %s %s :Nick/channel is temporarily unavailable",
-/* 438 ERR_BANNICKCHANGE */     ":%s 438 %s %s :The hand of the deity is upon you, thy nick may not change",
+/* 438 ERR_BANNICKCHANGE */     ":%s 438 %s %s :The hand of the deity is upon thee, thy nick may not change",
 /* 439 */       (char *)NULL,
 /* 440 */       (char *)NULL,
 /* 441 ERR_USERNOTINCHANNEL, */ ":%s 441 %s %s %s :They aren't on that channel",
@@ -490,7 +490,7 @@
 /* 445 ERR_SUMMONDISABLED, */   ":%s 445 %s :SUMMON has been removed",
 /* 446 ERR_USERSDISABLED, */    ":%s 446 %s :USERS has been removed",
 /* 447 ERR_TARGETNINVITE, */    ":%s 447 %s :User has opted not to receive INVITEs (umode +I)",
-/* 448 ERR_SOURCENINVITE, */    ":%s 448 %s :You may not send INVITEs with umode I set",
+/* 448 ERR_SOURCENINVITE, */    ":%s 448 %s :You may not send INVITEs with umode +I set",
 /* 449 */       (char *)NULL,
 /* 450 */       (char *)NULL,
 /* 451 ERR_NOTREGISTERED, */    ":%s 451 %s :You haven't registered yet",
@@ -525,7 +525,7 @@
 /* 480 */	(char *)NULL,
 /* 481 ERR_NOPRIVILEGES, */
                 ":%s 481 %s :Permission Denied - You're no deity",
-/* 482 ERR_CHANOPRIVSNEEDED, */ ":%s 482 %s %s :You need to be an operator to do that",
+/* 482 ERR_CHANOPRIVSNEEDED, */ ":%s 482 %s %s :You need to be a channel operator to do that",
 /* 483 ERR_CANTKILLSERVER, */    ":%s 483 %s :You can't actually kill an IRC server that way.",
 /* 484 */       (char *)NULL,
 /* 485 ERR_USERISIMMUNE, */     ":%s 485 %s %s %s :User is immune from kick/deop",
diff -ruN -x configure -x *~ -x ircd-hybrid-6.0.orig -x *.rej ircd-hybrid-6.0.orig/src/s_user.c ircd-hybrid-6.0/src/s_user.c
--- ircd-hybrid-6.0.orig/src/s_user.c	Sat Jun  9 17:59:46 2001
+++ ircd-hybrid-6.0/src/s_user.c	Sat Jun  9 17:45:32 2001
@@ -298,8 +298,12 @@
   if (Count.chan > 0)
     sendto_one(sptr, form_str(RPL_LUSERCHANNELS),
                me.name, parv[0], Count.chan);
-  sendto_one(sptr, form_str(RPL_LUSERME),
-             me.name, parv[0], m_client, m_server);
+  if (IsSetOperAuspex(sptr))
+    sendto_one(sptr, form_str(RPL_LUSERME),
+	       me.name, parv[0], m_client, m_server);
+  else
+    sendto_one(sptr, form_str(RPL_LUSERME),
+	       me.name, parv[0], m_client, 0);
   sendto_one(sptr, form_str(RPL_LOCALUSERS), me.name, parv[0],
              Count.local, Count.max_loc);
   sendto_one(sptr, form_str(RPL_GLOBALUSERS), me.name, parv[0],
